:mod:`euphorie.client.browser.login`
====================================

.. automodule:: euphorie.client.browser.login


Views
-----

.. autoclass:: Login
   :members:

.. autoclass:: Tryout
   :members:

.. autoclass:: CreateTestSession
   :members:

.. autoclass:: Logout
   :members:
